/*

Room presets:
Preset 0, 10, 20, 30, 14, Standby, Deepoff: off
Preset 1: 100% white / temp: 2700K
Preset 2: 75% white / temp: 2700K
Preset 3: 50% white / temp: 2700K
Preset 4: 25% white / temp: 2700K

We should summarise all the off-setting in one row, while this row cannot be edited. So it’s the same setting as the sonos app defines.
An open point is whether the presets 11-14, 21-24, 31-34, 41-44 will be added as well.

Activities:
Leaving home: off
panic: 100% white / temp: 4000K
Fire: 100% white / temp: 4000K
Sleeping: off


*/


/* "off" presets are handled internally */


/* fallback defaults for when no appropiate light settings are available in the tables */
var standardLightSettings = {
	globalActivity: {
		on: true,
		color: [ 1, 0, 1 ], // hue, saturation, value
		blinking: false,
		useCT: false, // CT = color temperature
		ct: 500, // in Mired units
		ctbri: 255 // separate brightness for color temperature
	},

	preset: {
		on: true,
		color: [ 1, 0, 1 ], // hue, saturation, value
		blinking: false,
		useCT: false, // CT = color temperature
		ct: 500, // in Mired units
		ctbri: 255 // separate brightness for color temperature
	}
};


var standardGlobalActivities = [
	// "leaving home"
	{
		triggers: [
			{
				type: "zone-scene",
				zone: 0,
				group: 0,
				scene: 72,
				dsuid: -1
			}
		],
		lightSettings: {
			on: false,
			color: [ 0, 0, 0 ],
			blinking: false,
			useCT: false,
			ct: 500,
			ctbri: 255
		}
	},
	// "panic"
	{
		triggers: [
			{
				type: "zone-scene",
				zone: 0,
				group: 0,
				scene: 65,
				dsuid: -1
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 250, // 250 mired = 4000 Kelvin
			ctbri: 255
		}
	},
	// "fire"
	{
		triggers: [
			{
				type: "state-change",
				name: "fire",
				state: "active"
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 250, // 250 mired = 4000 Kelvin
			ctbri: 255
		}
	},
	// "sleeping"
	{
		triggers: [
			{
				type: "zone-scene",
				zone: 0,
				group: 0,
				scene: 69,
				dsuid: -1
			}
		],
		lightSettings: {
			on: false,
			color: [ 0, 0, 0 ],
			blinking: false,
			useCT: false,
			ct: 500,
			ctbri: 255
		}
	}
];


// for preset triggers, the "zone" property is automatically added later
var standardPresets = [
	// "preset 1"
	{
		triggers: [
			{
				type: "zone-scene",
				group: 1,
				scene: 5,
				dsuid: -1
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 370, // 370 mired ~ 2700 Kelvin
			ctbri: 255
		}
	},
	// "preset 2"
	{
		triggers: [
			{
				type: "zone-scene",
				group: 1,
				scene: 17,
				dsuid: -1
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 370, // 370 mired ~ 2700 Kelvin
			ctbri: 191
		}
	},
	// "preset 3"
	{
		triggers: [
			{
				type: "zone-scene",
				group: 1,
				scene: 18,
				dsuid: -1
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 370, // 370 mired ~ 2700 Kelvin
			ctbri: 127
		}
	},
	// "preset 4"
	{
		triggers: [
			{
				type: "zone-scene",
				group: 1,
				scene: 19,
				dsuid: -1
			}
		],
		lightSettings: {
			on: true,
			color: [ 1, 0, 1 ],
			blinking: false,
			useCT: true,
			ct: 370, // 370 mired ~ 2700 Kelvin
			ctbri: 63
		}
	}
];

